rm(list = ls())
library(kernlab)

# load data from UCI machine-learning repository
wisc <- read.table("http://archive.ics.uci.edu/ml/machine-learning-databases/breast-cancer-wisconsin/wdbc.data", sep = ",")
# or from local file
wisc <- read.table("wdbc.txt")

x <- matrix(unlist(wisc[,-c(1,2)]), ncol = 30)
y <- 2*as.numeric(unlist(wisc[,2])) - 3
n <- length(y)
p <- length(x)/n
H <- 10

# pre-sdr
z <- .std(x)$z  # standardization of x
lambda.grid <- unique(c((1:10)*(10^(-4)), c((1:10)*(10^(-3)), (1:10)*(10^(-2)), (1:10)*(10^(-1))))) # lambda grid for tunning
lambda <- .tune(z, y, kernel = "rbfdot", 
                kpar = list(sigma = 1/(2*(.mdist(z, y))^2)), 
                n.cross = 5, 
                grid = lambda.grid)

sigma <- 1/(2*(.mdist(z, y))^2)

pre1 <- presir(x, y, n.slices = H, kernel = "rbfdot", kparam = sigma, lambda = lambda)
pre2 <- presir2(x, y, n.slices = H, order = NULL, rank.type = "average", kernel = "rbfdot", kparam = sigma, lambda = lambda)
pre3 <- precume(x, y, order = pre2$order, rank.type = "average", kernel = "rbfdot", kparam = sigma, lambda = lambda)

presir1 <- pre1$evectors
presir2 <- pre2$evectors
presir3 <- pre3$evectors

x.pre1 <- x %*% presir1
x.pre2 <- x %*% presir2
x.pre3 <- x %*% presir3

par(mar = c(5, 4, 4, 2) + 0.5, mfrow = c(1,3))
dr.plot(x.pre1[,1:2], y,  main = "PRE-SIR1")
dr.plot(x.pre2[,1:2], y,  main = "PRE-SIR2")
dr.plot(x.pre3[,1:2], y,  main = "PRE-CUME")
